#
# spec file for package kodi
#
# Copyright (c) 2015-2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Please edit kodi.spec and kodi.changes only. *-noX.* files are generated from
# kodi.* files with the pre_checkin.sh script
%define kodi_version Omega
%define _kodi_addons_dir %{_datadir}/kodi/addons
# set this parameter to enable building Kodi with ccache, debug information, etc.
%define dev_build 0

# WARNING: Build with bundled ffmpeg until version 18.0 is reached
# INFO: We are on version 21.0 in the meantime, so let's live with
#  the system provided ffmpeg packages; if this won't work at some
#  point in time in the future, uncomment the "sysffmpeg" stuff. In
#  order to reduce downloading it every time, this is now commented!
%bcond_without sysffmpeg
## %if 0%{without sysffmpeg}
## %define ffmpeg_version 5.1.2-Nexus-Alpha3
## %endif

# kodi can be built without X support when openGL ES is used (mainly used on ARM boards used as media center)
%bcond_without kodi_with_X11
# Enable or disable Wayland depending on whether the stack is usable or not:
%if 0%{?suse_version} >= 1550
%bcond_without kodi_with_wayland
%else
%bcond_with kodi_with_wayland
%endif

%if 0%{?suse_version} < 1550
# Pipewire currently creates more issues than benefits; disable it for now:
%bcond_without kodi_without_pipewire
%else
# Leave PW enabled on Tumbleweed:
%bcond_with kodi_without_pipewire
%endif

%define kodi_platform none
%define kodi_player none

%if %{with kodi_with_X11}
%bcond_without enable_opengl
%bcond_with enable_opengles
%else
# no X build needs openGL ES
%bcond_with enable_opengl
%bcond_without enable_opengles
%endif
#
%bcond_without kodi_libbluray
# 
%bcond_without systemd

ExclusiveArch: %ix86 x86_64 %arm aarch64

Name:           kodi
Version:        21.2
Release:        1699.11.pm.5
Summary:        Media center (formerly known as XBMC)
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Multimedia/Video/Players
Url:            https://kodi.tv/
Source0:        https://github.com/xbmc/xbmc/archive/%{version}-%{kodi_version}.tar.gz
Source1:        kodi.SuSEFirewall2
# AUTO-GENERATED using get_version.sh
Source3:        kodi.VERSION
Source10:       kodi.service
Source11:       kodi-noX.service

# The following sources will be downloaded via _service's download_files:
Source20:       https://mirrors.kodi.tv/build-deps/sources/crossguid-ca1bf4b810e2d188d04cb6286f957008ee1b7681.tar.gz
Source21:	https://github.com/xbmc/libdvdnav/archive/refs/tags/6.1.1-Next-Nexus-Alpha2-2.tar.gz
Source22:	https://github.com/xbmc/libdvdcss/archive/refs/tags/1.4.3-Next-Nexus-Alpha2-2.tar.gz
Source23:       https://github.com/xbmc/libdvdread/archive/refs/tags/6.1.3-Next-Nexus-Alpha2-2.tar.gz
Source24:       https://mirrors.kodi.tv/build-deps/sources/libudfread-1.1.2.tar.gz
Source25:       https://mirrors.kodi.tv/build-deps/sources/apache-groovy-binary-4.0.16.zip

## %if 0%{without sysffmpeg}
## Source30:       https://github.com/xbmc/FFmpeg/archive/refs/tags/%{ffmpeg_version}.tar.gz
## %endif
Patch1:         0001-crossguid-dgb.patch
Patch2:         0002-kodi-install.patch
%if %{without kodi_with_wayland}
Patch3:         0003-kodi-disable-wayland.patch
%endif
%if %{without kodi_without_pipewire}
Patch4:         0004-kodi-workaround-pipewire-bug.patch
%endif
Patch5:         0005-kodi-comply-with-pipewire-prototypes.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  binutils-gold
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gawk
%if 0%{?suse_version} >= 1550 && 0%{?sle_version} == 0
# Use the default compiler on Tumbleweed
BuildRequires:	gcc
BuildRequires:  gcc-c++
%else
%if 0%{?suse_version} > 1320 && 0%{?sle_version} == 0
BuildRequires:	gcc9
BuildRequires:  gcc9-c++
%else
BuildRequires:  gcc8
BuildRequires:  gcc8-c++
%endif
%endif
BuildRequires:  ghostscript
BuildRequires:  graphviz
BuildRequires:  groff-full
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  flatbuffers-devel
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(fstrcmp)
BuildRequires:  pkgconfig(RapidJSON) >= 1.0.2
BuildRequires:  python(abi) >= 3.11
BuildRequires:  pkgconfig(python-3.11)
BuildRequires:  libmysqlclient-devel
BuildRequires:  pkgconfig(libass) >= 0.17.0
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  lzo-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  tinyxml-devel
BuildRequires:  tinyxml2-devel
BuildRequires:  pkgconfig(uuid)
BuildRequires:  libyajl-devel >= 2
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(sqlite3) 
BuildRequires:  pkgconfig(libpcrecpp)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(taglib) >= 1.9
BuildRequires:  pkgconfig(libcdio) >= 2.1.0
BuildRequires:  pkgconfig(lirc)
BuildRequires:  pkgconfig(RapidJSON)
%if %{with kodi_libbluray}
BuildRequires:  pkgconfig(libbluray)  >= 0.9.3
%endif
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
# libmicrohttpd > 0.9.30
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libpulse) >= 1.0
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(gbm)
%if %{with kodi_with_X11}
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(xkbcommon)
%endif
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(libnfs) >= 4.0.0
%if 0%{?suse_version} >= 1550 || ( 0%{?sle_version} >= 150400 && 0%{?is_opensuse} )
BuildRequires:  pkgconfig(libplist-2.0)
%else
BuildRequires:  pkgconfig(libplist)
%endif
BuildRequires:  shairplay-devel
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libcec) >= 4.0.0
BuildRequires:  pkgconfig(lcms2)
%if 0%{?suse_version} > 1315
BuildRequires:  pkgconfig(bluez)
%endif
BuildRequires:  libcap-devel
%if %{with sysffmpeg}
BuildRequires:  (pkgconfig(libavcodec) >= 60 with pkgconfig(libavcodec) < 61)
BuildRequires:  (pkgconfig(libavfilter) >= 9 with pkgconfig(libavfilter) < 10)
BuildRequires:  (pkgconfig(libavformat) >= 60 with pkgconfig(libavformat) < 61)
BuildRequires:  (pkgconfig(libavutil) >= 58 with pkgconfig(libavutil) < 59)
BuildRequires:  (pkgconfig(libpostproc) >= 57 with pkgconfig(libpostproc) < 58)
BuildRequires:  (pkgconfig(libswresample) >= 4 with pkgconfig(libswresample) < 5)
BuildRequires:  (pkgconfig(libswscale) >= 7 with pkgconfig(libswscale) < 8)
%else
BuildRequires:  ladspa-devel
BuildRequires:  libgsm-devel
BuildRequires:  pkg-config
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(celt) >= 0.11.0
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(fontconfig) >= 2.4.2
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi) >= 0.19.0
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libbluray)
BuildRequires:  pkgconfig(libcdio_paranoia)
BuildRequires:  pkgconfig(libdc1394-2)
BuildRequires:  pkgconfig(liboil-0.3) >= 0.3.15
BuildRequires:  pkgconfig(libopenjpeg)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libraw1394)
BuildRequires:  pkgconfig(libwebp) >= 0.4
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(schroedinger-1.0)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(theora) >= 1.1
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vpx) >= 1.3.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-shm)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(librtmp)
BuildRequires:  libmp3lame-devel
BuildRequires:  libxvidcore-devel
BuildRequires:  pkgconfig(opencore-amrnb)
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(x265)
%endif
BuildRequires:  swig < 4.2
BuildRequires:  java
BuildRequires:  apache-commons-lang3
BuildRequires:  apache-commons-text
BuildRequires:  doxygen
%if %{with enable_opengl}
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(vdpau)
%if 0%{?suse_version} < 1500
BuildRequires:  pkgconfig(libva) >= 0.38
BuildRequires:  pkgconfig(libva-x11) >= 0.38
%else
BuildRequires:  pkgconfig(libva) >= 1.0.0
BuildRequires:  pkgconfig(libva-x11) >= 1.0.0
%endif
%endif
BuildRequires:  pkgconfig(libdisplay-info)
%if %{with kodi_with_wayland}
BuildRequires:  pkgconfig(libva-wayland)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-scanner++)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-client++)
BuildRequires:  pkgconfig(wayland-cursor++)
BuildRequires:  pkgconfig(wayland-egl++)
%endif
%if %{with enable_opengles}
%if "%{kodi_platform}" == "none"
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%else
%if ("%{kodi_platform}" == "raspberry-pi") || ("%{kodi_platform}" == "raspberry-pi2")
BuildRequires:  raspberrypi-userland-devel
%endif
%endif
%endif
%if "%{kodi_player}" == "omxplayer"
Requires:       omxplayer
%endif
BuildRequires:  cmake
BuildRequires:  gperf
BuildRequires:  unzip
BuildRequires:  zip
BuildRequires:  nasm
%if %{dev_build}
BuildRequires:  ccache
%endif

# cpluff
BuildRequires:  pkgconfig(expat)

# TexturePacker
BuildRequires:  pkgconfig(libpng)
BuildRequires:  giflib-devel
BuildRequires:  libjpeg8-devel
BuildRequires:  lzo-devel
#
BuildRequires:  pkgconfig(spdlog) > 1.8.0
BuildRequires:  libunistring-devel

%if 0%{?suse_version} > 1510
BuildRequires:  pkgconfig(gtest)
%else
BuildRequires: googletest-devel
%endif

%if %{without kodi_without_pipewire}
# pipewire
BuildRequires: pkgconfig(libpipewire-0.3)
BuildRequires: pkgconfig(libspa-0.2)
%endif
#
%{?systemd_requires}

# kodi needs libnfs to access nfs sources, it is not automatically required
Requires:       libnfs
#
Obsoletes:      xbmc < %{version}
Provides:       xbmc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with kodi_with_X11}
Conflicts:      kodi
%else
Conflicts:      kodi-noX
%endif


%description
KODI media center is a free cross-platform media-player jukebox and
entertainment hub.  KODI can play a spectrum of of multimedia formats,
and featuring playlist, audio visualizations, slideshow, and weather
forecast functions, together third-party plugins.

%package devel
Summary:        Kodi Media center devel files
Group:          Development/Languages/C and C++
Requires:       %{name}
BuildArch:      noarch
%if %{with kodi_with_X11}
Conflicts:      kodi-devel
%else
Conflicts:      kodi-noX-devel
%endif

%description devel
Development files for Kodi Media Center

%prep
%setup -q -n xbmc-%{version}-%{kodi_version}
%autopatch -p1

%build

# Remove build time references so build-compare can do its work
date -u -r version.txt +%%Y%%m%%d | tee BUILDDATE 
FAKE_BUILDDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes)
for file in xbmc/interfaces/python/PythonSwig.cpp.template ; do
  sed -i -e "/PyModule_AddStringConstant.*__date__/ s/\${new Date()\.toString()}/$FAKE_BUILDDATETIME/"  $file
done

# Set the final version string
cp %{SOURCE3} VERSION

# avoid long delays when powerkit isn't running
sed -i \
    -e '/dbus_connection_send_with_reply_and_block/s:-1:3000:' \
    xbmc/platform/linux/*.cpp

%if "%{kodi_platform}" == "raspberry-pi" || "%{kodi_platform}" == "raspberry-pi2"
export CXXFLAGS="$CXXFLAGS -I%{_includedir}/interface/vcos/pthreads -I%{_includedir}/interface/vmcs_host/linux"
%endif

%if 0%{?suse_version} >= 1550 && 0%{?sle_version} == 0
 export CC=gcc
 export CXX=g++
%else
%if 0%{?suse_version} > 1320 && 0%{?sle_version} == 0
 export CC=gcc-9
 export CXX=g++-9
%else
 export CC=gcc-8
 export CXX=g++-8
%endif
%endif

# Extract the groovy files to a proper place:
mkdir -p %{_builddir}/groovy
unzip %{SOURCE25} -d %{_builddir}/groovy
mv %{_builddir}/groovy/groovy-*/lib %{_builddir}/groovy
rm -rf %{_builddir}/groovy/groovy-* || true

%cmake \
%ifarch i586
    -DCMAKE_C_FLAGS='-msse' \
%endif
%if %{dev_build}
    -DVERBOSE=ON \
%endif
%if %{with kodi_with_wayland}
    -DWAYLANDPP_INCLUDE_DIR="$(pkg-config --cflags-only-I wayland-client++ | sed -e 's/^-I//;s/ -I/;/g;s/ $//')" \
%endif
    -DCMAKE_C_COMPILER=$CC \
    -DCMAKE_CXX_COMPILER=$CXX \
    -DENABLE_INTERNAL_FMT=OFF \
%if %{without sysffmpeg}
    -DENABLE_INTERNAL_FFMPEG=ON \
    -DFFMPEG_URL=%{SOURCE30} \
%else
    -DENABLE_INTERNAL_FFMPEG=OFF \
%endif
    -DENABLE_INTERNAL_CDIO=OFF \
    -DENABLE_INTERNAL_SPDLOG=OFF \
    -DCROSSGUID_URL=%{SOURCE20} \
    -DLIBDVDNAV_URL=%{SOURCE21} \
    -DLIBDVDCSS_URL=%{SOURCE22} \
    -DLIBDVDREAD_URL=%{SOURCE23} \
    -DENABLE_INTERNAL_RapidJSON=OFF \
    -DENABLE_INTERNAL_FLATBUFFERS=OFF \
    -DENABLE_INTERNAL_FSTRCMP=OFF \
    -DENABLE_INTERNAL_UDFREAD=ON \
    -DUDFREAD_URL=%{SOURCE24} \
    -Dgroovy_SOURCE_DIR=%{_builddir}/groovy \
    -Dapache-commons-lang_SOURCE_DIR=%{_datadir}/java \
    -Dapache-commons-text_SOURCE_DIR=%{_datadir}/java/apache-commons-text \
    -DAPP_RENDER_SYSTEM=gl \
    -DX11_RENDER_SYSTEM=gl \
    -DBUILD_SHARED_LIBS=1 \
    -DPYTHON_VER=3.11 \
%if %{with kodi_without_pipewire}
    -DENABLE_PIPEWIRE=OFF \
%endif
    ${NULL}

make -O %{?_smp_mflags} V=1 CC=$CC CXX=$CXX || l
rm -rf %{_builddir}/groovy

%install
pushd build
make DESTDIR=%{buildroot} install %{?_smp_mflags}
#make -C tools/EventClients DESTDIR=%%{buildroot} install %%{?_smp_mflags}

# Tumbleweed does not have SuSEfirewall anymore:
%if 0%{?is_opensuse} == 0 || 0%{?suse_version} < 1550
# SuSEfirewall service description
install -D -m 644 %{_sourcedir}/kodi.SuSEFirewall2 %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/kodi
%endif

# Systemd service file
%if %{without kodi_with_X11}
install -m 0644 -D %{SOURCE11} %{buildroot}/%{_unitdir}/kodi-noX.service
%else
install -m 0644 -D %{SOURCE10} %{buildroot}/%{_unitdir}/kodi.service
%endif

# remove the doc files from unversioned /usr/share/doc/kodi, they should be in versioned docdir
rm -r %{buildroot}/%{_datadir}/doc/

# remove win32 source files
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/dlfcn-win32.cpp
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/dlfcn-win32.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/dlfcn-win32.cpp
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/dlfcn-win32.h

# remove duplicate header files
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/libXBMC_addon.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/libXBMC_addon.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.codec/libXBMC_codec.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.codec/libXBMC_codec.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.gui/libXBMC_gui.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.gui/libXBMC_gui.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.pvr/libXBMC_pvr.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.pvr/libXBMC_pvr.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.guilib/libKODI_guilib.h

# copy manpages
popd
install -m 644 -D docs/manpages/kodi-standalone.1 %{buildroot}%{_mandir}/man1/kodi-standalone.1
install -m 644 -D docs/manpages/kodi.bin.1 %{buildroot}%{_mandir}/man1/kodi.1

desktop-file-install \
 --dir=%{buildroot}%{_datadir}/applications \
 %{buildroot}%{_datadir}/applications/kodi.desktop

%if %{without kodi_with_wayland}
rm -f %{buildroot}%{_datadir}/wayland-sessions/kodi-gbm.desktop
rmdir -p %{buildroot}%{_datadir}/wayland-sessions || true
%endif

# TexturePacker likes to be installed as kodi-TexturePacker, too.
if [ -f %{buildroot}%{_bindir}/kodi-TexturePacker ] && [ -f %{buildroot}%{_bindir}/TexturePacker ]; then
    rm -f %{buildroot}%{_bindir}/TexturePacker
elif [ -f %{buildroot}%{_bindir}/TexturePacker ]; then
    mv %{buildroot}%{_bindir}/TexturePacker %{buildroot}%{_bindir}/kodi-TexturePacker
fi
%fdupes %{buildroot}

%pre
%service_add_pre kodi.service

%post
%service_add_post kodi.service

%preun
%service_del_preun kodi.service

%postun
%service_del_postun kodi.service

%files
%defattr(-,root,root)
%doc version.txt 
%if 0%{?is_opensuse} == 0 || 0%{?suse_version} < 1550
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/kodi
%endif
%{_bindir}/kodi
%{_bindir}/kodi-standalone
%{_bindir}/kodi-TexturePacker
%dir %{_libdir}/kodi
%if %{with kodi_with_X11}
%{_libdir}/kodi/kodi-xrandr
%{_libdir}/kodi/kodi.bin
%endif
%{_datadir}/xsessions/kodi.desktop
%if %{with kodi_with_wayland}
%dir %{_datadir}/wayland-sessions
%{_datadir}/wayland-sessions/kodi-gbm.desktop
%endif
%{_datadir}/applications/kodi.desktop
%{_datadir}/metainfo/org.xbmc.kodi.metainfo.xml
%{_datadir}/icons/*
%dir %{_datadir}/kodi
%dir %{_datadir}/kodi/media
%dir %{_datadir}/kodi/system
%dir %{_libdir}/kodi/system
%dir %{_datadir}/kodi/userdata
%{_datadir}/kodi/media/*
%{_datadir}/kodi/system/*
%{_datadir}/kodi/privacy-policy.txt
%{_libdir}/kodi/system/*
%{_datadir}/kodi/userdata/*
%{_mandir}/man1/kodi.1.gz
%{_mandir}/man1/kodi-standalone.1.gz
%dir %{_kodi_addons_dir}
%dir %{_kodi_addons_dir}/game.controller.default
%{_kodi_addons_dir}/game.controller.default/*
%dir %{_kodi_addons_dir}/game.controller.keyboard
%{_kodi_addons_dir}/game.controller.keyboard/*
%dir %{_kodi_addons_dir}/game.controller.mouse
%{_kodi_addons_dir}/game.controller.mouse/*
%dir %{_kodi_addons_dir}/game.controller.snes
%{_kodi_addons_dir}/game.controller.snes/*
%dir %{_kodi_addons_dir}/metadata.album.universal/
%{_kodi_addons_dir}/metadata.album.universal/*
%dir %{_kodi_addons_dir}/metadata.artists.universal/
%{_kodi_addons_dir}/metadata.artists.universal/*
%dir %{_kodi_addons_dir}/metadata.common.allmusic.com/
%{_kodi_addons_dir}/metadata.common.allmusic.com/*
%dir %{_kodi_addons_dir}/metadata.common.fanart.tv/
%{_kodi_addons_dir}/metadata.common.fanart.tv/*
%dir %{_kodi_addons_dir}/metadata.common.musicbrainz.org/
%{_kodi_addons_dir}/metadata.common.musicbrainz.org/*
%dir %{_kodi_addons_dir}/metadata.common.theaudiodb.com/
%{_kodi_addons_dir}/metadata.common.theaudiodb.com/*
%dir %{_kodi_addons_dir}/metadata.local/
%{_kodi_addons_dir}/metadata.local/*
%dir %{_kodi_addons_dir}/metadata.themoviedb.org.python/
%{_kodi_addons_dir}/metadata.themoviedb.org.python/*
%dir %{_kodi_addons_dir}/metadata.tvshows.themoviedb.org.python/
%{_kodi_addons_dir}/metadata.tvshows.themoviedb.org.python/*
%dir %{_kodi_addons_dir}/repository.xbmc.org/
%{_kodi_addons_dir}/repository.xbmc.org/*
%dir %{_kodi_addons_dir}/resource.uisounds.kodi/
%{_kodi_addons_dir}/resource.uisounds.kodi/*
%dir %{_kodi_addons_dir}/screensaver.xbmc.builtin.black/
%{_kodi_addons_dir}/screensaver.xbmc.builtin.black/*
%dir %{_kodi_addons_dir}/screensaver.xbmc.builtin.dim/
%{_kodi_addons_dir}/screensaver.xbmc.builtin.dim/*
%dir %{_kodi_addons_dir}/script.module.pil/
%{_kodi_addons_dir}/script.module.pil/*
%dir %{_kodi_addons_dir}/service.xbmc.versioncheck/
%{_kodi_addons_dir}/service.xbmc.versioncheck/*
%dir %{_kodi_addons_dir}/webinterface.default/
%{_kodi_addons_dir}/webinterface.default/*
%dir %{_kodi_addons_dir}/xbmc.addon/
%{_kodi_addons_dir}/xbmc.addon/*
%dir %{_kodi_addons_dir}/xbmc.core/
%{_kodi_addons_dir}/xbmc.core/*
%dir %{_kodi_addons_dir}/xbmc.gui/
%{_kodi_addons_dir}/xbmc.gui/*
%dir %{_kodi_addons_dir}/xbmc.json/
%{_kodi_addons_dir}/xbmc.json/*
%dir %{_kodi_addons_dir}/xbmc.metadata/
%{_kodi_addons_dir}/xbmc.metadata/*
%dir %{_kodi_addons_dir}/xbmc.python/
%{_kodi_addons_dir}/xbmc.python/*
%dir %{_kodi_addons_dir}/audioencoder.kodi.builtin.aac/
%{_kodi_addons_dir}/audioencoder.kodi.builtin.aac/*
%dir %{_kodi_addons_dir}/audioencoder.kodi.builtin.wma/
%{_kodi_addons_dir}/audioencoder.kodi.builtin.wma/*
%dir %{_kodi_addons_dir}/kodi.resource/
%{_kodi_addons_dir}/kodi.resource/*
%dir %{_kodi_addons_dir}/resource.language.en_gb/
%{_kodi_addons_dir}/resource.language.en_gb/*
%dir %{_kodi_addons_dir}/xbmc.webinterface/
%{_kodi_addons_dir}/xbmc.webinterface/*
%dir %{_kodi_addons_dir}/resource.images.weathericons.default
%{_kodi_addons_dir}/resource.images.weathericons.default/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.inputstream/
%{_kodi_addons_dir}/kodi.binary.instance.inputstream/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.audioencoder/
%{_kodi_addons_dir}/kodi.binary.instance.audioencoder/*
%dir %{_kodi_addons_dir}/skin.estuary
%{_kodi_addons_dir}/skin.estuary/*
%dir %{_kodi_addons_dir}/kodi.binary.global.audioengine
%{_kodi_addons_dir}/kodi.binary.global.audioengine/*
%dir %{_kodi_addons_dir}/kodi.binary.global.filesystem
%{_kodi_addons_dir}/kodi.binary.global.filesystem/*
%dir %{_kodi_addons_dir}/kodi.binary.global.general
%{_kodi_addons_dir}/kodi.binary.global.general/*
%dir %{_kodi_addons_dir}/kodi.binary.global.gui
%{_kodi_addons_dir}/kodi.binary.global.gui/*
%dir %{_kodi_addons_dir}/kodi.binary.global.main
%{_kodi_addons_dir}/kodi.binary.global.main/*
%dir %{_kodi_addons_dir}/kodi.binary.global.network
%{_kodi_addons_dir}/kodi.binary.global.network/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.audiodecoder
%{_kodi_addons_dir}/kodi.binary.instance.audiodecoder/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.game
%{_kodi_addons_dir}/kodi.binary.instance.game/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.imagedecoder
%{_kodi_addons_dir}/kodi.binary.instance.imagedecoder/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.peripheral
%{_kodi_addons_dir}/kodi.binary.instance.peripheral/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.pvr
%{_kodi_addons_dir}/kodi.binary.instance.pvr/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.screensaver
%{_kodi_addons_dir}/kodi.binary.instance.screensaver/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.vfs
%{_kodi_addons_dir}/kodi.binary.instance.vfs/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.videocodec
%{_kodi_addons_dir}/kodi.binary.instance.videocodec/*
%dir %{_kodi_addons_dir}/kodi.binary.instance.visualization
%{_kodi_addons_dir}/kodi.binary.instance.visualization/*
%dir %{_kodi_addons_dir}/script.module.pycryptodome
%{_kodi_addons_dir}/script.module.pycryptodome/*
%dir %{_kodi_addons_dir}/metadata.generic.albums
%{_kodi_addons_dir}/metadata.generic.albums/*
%dir %{_kodi_addons_dir}/metadata.generic.artists
%{_kodi_addons_dir}/metadata.generic.artists/*
%dir %{_kodi_addons_dir}/kodi.binary.global.tools
%{_kodi_addons_dir}/kodi.binary.global.tools/*

%dir %{_libdir}/firewalld
%dir %{_libdir}/firewalld/services
%{_libdir}/firewalld/services/kodi-eventserver.xml
%{_libdir}/firewalld/services/kodi-http.xml
%{_libdir}/firewalld/services/kodi-jsonrpc.xml

%if %{without kodi_with_X11}
%{_unitdir}/kodi-noX.service
%else
%{_unitdir}/kodi.service
%endif

%dir %{_datadir}/kodi/cmake
%{_datadir}/kodi/cmake/AddonHelpers.cmake
%{_datadir}/kodi/cmake/AddOptions.cmake
%{_datadir}/kodi/cmake/ArchSetup.cmake
%{_datadir}/kodi/cmake/CheckCommits.cmake
%{_datadir}/kodi/cmake/CheckTargetPlatform.cmake
%{_datadir}/kodi/cmake/GenerateCompileInfo.cmake
%{_datadir}/kodi/cmake/GeneratorSetup.cmake
%{_datadir}/kodi/cmake/HandleDepends.cmake
%{_datadir}/kodi/cmake/Macros.cmake
%{_datadir}/kodi/cmake/PrepareEnv.cmake
%{_datadir}/kodi/cmake/ProjectMacros.cmake
%{_datadir}/kodi/cmake/PathSetup.cmake
%dir %{_libdir}/kodi/cmake
%{_libdir}/kodi/cmake/KodiConfig.cmake

%{_datadir}/metainfo/org.xbmc.kodi.metainfo.xml

%files devel
%defattr(-,root,root)
%dir %{_includedir}/kodi
%dir %{_includedir}/kodi/tools
%{_includedir}/kodi/tools/DllHelper.h
%{_includedir}/kodi/AddonBase.h
%{_includedir}/kodi/AudioEngine.h
%{_includedir}/kodi/Filesystem.h
%{_includedir}/kodi/General.h
%{_includedir}/kodi/Network.h
%{_includedir}/kodi/versions.h
%dir %{_includedir}/kodi/addon-instance
%{_includedir}/kodi/addon-instance/*
%dir %{_includedir}/kodi/addon-instance/inputstream
%{_includedir}/kodi/addon-instance/inputstream/*
%dir %{_includedir}/kodi/addon-instance/peripheral
%{_includedir}/kodi/addon-instance/peripheral/*
%dir %{_includedir}/kodi/addon-instance/pvr
%{_includedir}/kodi/addon-instance/pvr/*
%dir %{_includedir}/kodi/c-api
%{_includedir}/kodi/c-api/*
%dir %{_includedir}/kodi/c-api/addon-instance
%{_includedir}/kodi/c-api/addon-instance/*
%dir %{_includedir}/kodi/c-api/addon-instance/inputstream
%{_includedir}/kodi/c-api/addon-instance/inputstream/*
%dir %{_includedir}/kodi/c-api/addon-instance/pvr
%{_includedir}/kodi/c-api/addon-instance/pvr/*
%dir %{_includedir}/kodi/c-api/gui
%{_includedir}/kodi/c-api/gui/*
%dir %{_includedir}/kodi/c-api/gui/controls
%{_includedir}/kodi/c-api/gui/controls/*
%dir %{_includedir}/kodi/c-api/gui/dialogs
%{_includedir}/kodi/c-api/gui/dialogs/*
%dir %{_includedir}/kodi/c-api/gui/input
%{_includedir}/kodi/c-api/gui/input/*
%dir %{_includedir}/kodi/c-api/platform
%dir %{_includedir}/kodi/c-api/platform/android
%{_includedir}/kodi/c-api/platform/android/*
%dir %{_includedir}/kodi/gui
%{_includedir}/kodi/gui/*
%dir %{_includedir}/kodi/gui/controls
%{_includedir}/kodi/gui/controls/*
%dir %{_includedir}/kodi/gui/dialogs
%{_includedir}/kodi/gui/dialogs/*
%dir %{_includedir}/kodi/gui/gl
%{_includedir}/kodi/gui/gl/*
%dir %{_includedir}/kodi/gui/input
%{_includedir}/kodi/gui/input/*
%dir %{_includedir}/kodi/platform
%dir %{_includedir}/kodi/platform/android
%{_includedir}/kodi/platform/android/System.h
%dir %{_includedir}/kodi/tools
%{_includedir}/kodi/tools/*

%changelog
* Tue Feb 18 2025 <manfred.h@gmx.net>
- Add 0005-kodi-comply-with-pipewire-prototypes.patch to comply with
  Pipewire's newly added prototyped functions to work with a node's
  enum_params.
* Sun Jan 19 2025 <manfred.h@gmx.net>
- Upstream has changed the tag name to 21.2-Omega again; fix the
  name for Source0
* Fri Jan 17 2025 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 21.2 Omega
- Tag name has changed from 21.1-Omega into v21.2-Omega; reflect
  this in the value for Source0!
* Sat Nov  9 2024 Manfred Hollstein <manfred.h@gmx.net>
- Restrict swig version to < 4.2; newer versions on Tumbleweed do
  not accept all options used by kodi.
* Sun Aug 18 2024 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 21.1 Omega
* Tue May 14 2024 Manfred Hollstein <manfred.h@gmx.net>
- Ensure to stick with ffmpeg-6 related packages for building.
* Wed May  8 2024 Manfred Hollstein <manfred.h@gmx.net>
- Use https:// URLs only.
- Pipewire currently creates more issues than benefits on Leap;
  use new conditional "kodi_without_pipewire" to enable or disable it.
  We default to disable it now on Leap.
* Mon Apr 22 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add 0004-kodi-workaround-pipewire-bug.patch to work around a
  potentially broken pipewire installation on openSUSE Leap 15.5
  and 15.6; see https://bugzilla.opensuse.org/show_bug.cgi?id=1222636
* Sat Apr  6 2024 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 21.0 Omega
* Tue Mar 19 2024 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 21.0rc2 Omega
* Fri Mar 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Always assume "with sysffmpeg": All of our target platforms have
  a suitable version of ffmpeg packages, therefore comment most of
  the "with/without sysffmpeg" stuff which helps to avoid
  downloading an outdated tarball which doesn't get used at all.
- Make all other SourceN archives downloadable via _service.
- Do not restrict the Java version anymore.
* Thu Mar  7 2024 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 21.0rc1 Omega
- Remove 0004-xbmc#24733.patch
* Sun Feb 18 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add 0004-xbmc#24733.patch to fix
  * https://github.com/kodi-pvr/pvr.vuplus/issues/449
  * https://github.com/xbmc/xbmc/issues/24629
- Use %%%%autopatch -p1 to make RPM-4.19 happy.
* Fri Feb 16 2024 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 21.0b3 Omega
- Update build time dependendies.
- Add binary tarball for apache-groovy as Source25.
- Cleanup patches no longer needed:
  crossguid_build64.patch, disable_internal_libdvd.patch,
  kodi-15.0-gcc5.patch, kodi-apply-dvdrun.patch,
  kodi-libdrm.patch, kodi-sse.patch, kodi-texturepacker.patch,
  kodi-tools-libdir.patch, kodi.aarch64.patch, kodi.arm.patch,
  kodi.cximage.gcc6.patch, libdvdnav-no-return.patch,
  no-xbmc-symbolic-link.patch
- Rename .patch files to include a series number.
* Wed Jan 10 2024 Manfred Hollstein <manfred.h@gmx.net>
- Use python3.11 on all platforms.
- Restore the "|| l" in case of a make failure
- Add crossguid-dgb.patch as Patch3 to remove some strange
  libcrossguid-dgb references.
- Update build time dependendies.
- Update package files lists.
- Ensure kodi-TexturePacker is installed and not TexturePacker.
- Remove fix_building_with_fmt10.patch which is no longer needed.
- Remove ffmpeg-4.3.1-ogg.patch and kodi-apply-ffmpeg.patch which
  are no longer needed/wanted.
- Add source tarball for libudfread as Source24.
* Mon Dec 18 2023 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 21.0b2 Omega
* Tue Dec  5 2023 Manfred Hollstein <manfred.h@gmx.net>
- Unban fmt10, but add new patch fix_building_with_fmt10.patch
  derived from https://github.com/xbmc/xbmc/pull/23453 to fix
  building on current TW with updated libfmt10 and libspdlog12.
- Remove "alias l=..." and replace its use with the real command
* Fri Nov  3 2023 Manfred Hollstein <manfred.h@gmx.net>
- Don't use java >= 21 for building yet.
* Fri Aug 25 2023 Manfred Hollstein <manfred.h@gmx.net>
- Use the system's default compiler on Tumbleweed
- Enable pipewire support
* Thu Jul 13 2023 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 20.2 Nexus
* Sun May 21 2023 Manfred Hollstein <manfred.h@gmx.net>
- Ensure fmt10 is banned for now.
* Fri Mar 17 2023 Sagi Ben <sagiben@gmail.com>
- Version update to Kodi 20.1 Nexus
* Mon Jan 16 2023 Sagi Ben <sagiben@gmail.com>
- Version update to Kodi 20.0 Nexus
* Mon Jan  2 2023 Manfred Hollstein <manfred.h@gmx.net>
- Apply upstream patch as "fix_import_eglextchromium.patch" to fix
  compilation failure "EGL/eglextchromium.h: No such file or directory"
  with recent Mesa versions on TW; taken from
  https://github.com/xbmc/xbmc/pull/22291/commits/5449652abf0bb9dddd0d796de4120e60f19f89a5
* Mon Dec 26 2022 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 19.5 Matrix
  * "fix-formattable-string.patch" is no longer needed, remove it
  * Check if cmake/KodiConfig.cmake is installed at the proper
    location; if not, fix it
* Sun Dec 18 2022 Manfred Hollstein <manfred.h@gmx.net>
- Rewrite the ffmpeg specific version range using the proper rpm
  syntax: (cond1 with cond2)
* Sat Dec  3 2022 Manfred Hollstein <manfred.h@gmx.net>
- Explicitly request packages from the ffmpeg-4 branch to avoid
  pulling in ffmpeg-5 on TW
* Sun Oct 16 2022 Manfred Hollstein <manfred.h@gmx.net>
- Apply upstream patch to fix "formatting of non-void pointers is
  disallowed" on Tumbleweed caused by libfmt9; taken from
  https://github.com/xbmc/xbmc/commit/1d4e27aaa64c317b0020bbd68bb6520d507bb48e
  and
  https://github.com/xbmc/xbmc/commit/0ea4ec6e8965848ebe22e27c44ddfd8ab60a8bb6
* Tue Aug 16 2022 Dr. Werner Fink <werner@suse.de>
- Apply upstream patch to fix upstream ffmpeg version (issue#21603)
- Update ffmpeg upstream version iused by kodi project
* Wed Jul 20 2022 Manfred Hollstein <manfred.h@gmx.net>
- Use gcc12 on TW.
* Sun Mar 27 2022 Giacomo Comes <gcomes.obs@gmail.com>
- for Leap 15.4 use BuildRequires libplist-2.0
* Wed Mar  9 2022 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 19.4 Matrix
  * Don't rely on legacy versions of packages fmt and spdlog for
    openSUSE_Tumbleweed anymore. Package deletion for
    Multimedia/A_tw-fmt and
    Multimedia/A_tw-spdlog requested.
* Sun Oct 31 2021 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 19.3 Matrix
  * Add new file /usr/share/metainfo/org.xbmc.kodi.metainfo.xml
* Sun Oct 10 2021 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 19.2 Matrix
* Sun Jun 13 2021 Manfred Hollstein <manfred.h@gmx.net>
- Tumbleweed no longer has gcc9; switch to gcc10 for TW.
* Thu May 13 2021 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 19.1 Matrix
- libnfs must be at least version 4.0.0
* Tue Mar  9 2021 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 19.0 Matrix
* Thu Dec 31 2020 olaf@aepfle.de
- SSE does not depend on buildhost
* Mon Oct 26 2020 Manfred Hollstein <manfred.h@gmx.net>
- Version update to Kodi 18.9 Leia
  * Work around third-party changes to HTTP2 and SSL/encryption
    that impacted internet access from Kodi by scrapers, streaming
    addons, etc.
  * Fix memory leaks in TexturePacker
  * Fix event server unable to send raw key strikes
  * Fix issues around directory navigation and incorrectly-set
    start directories
  * Fix MediaCodec OES/EGL rendering
* Fri Jul 31 2020 Sagi <sagiben@gmail.com>
- Version update to Kodi 18.8 Leia
* Fri May 22 2020 manfred.h@gmx.net
- Version update to Kodi 18.7 Leia
* Fri May 22 2020 Sagi <sagiben@gmail.com>
- Version update to Kodi 18.7 Leia
* Mon Mar  9 2020 manfred.h@gmx.net
- Version update to Kodi 18.6 Leia
- 1157e9a11218945a14d9272814e78509c3e5b6c6.patch has been applied,
  remove it.
* Thu Dec  5 2019 olaf@aepfle.de
- Use flatbuffers from OBS
- Use fmt from OBS
- Use fstrcmp from OBS
- Use rapidjson from OBS
- Disable bluez on SLE_12
* Mon Nov 18 2019 Sagi <sagiben@gmail.com>
- Version update to Kodi 18.5 Leia
* Thu Oct 31 2019 manfred.h@gmx.net
- Use gcc-9/g++-9 on Tumbleweed/Factory.
* Wed Sep  4 2019 Sagi <sagiben@gmail.com>
- Version update to Kodi 18.4 Leia
* Sun Jun 23 2019 Sagi <sagiben@gmail.com>
- Version update to Kodi 18.3 Leia
* Tue Apr 23 2019 Sagi <sagiben@gmail.com>
- Version update to Kodi 18.2 Leia
* Sun Apr 14 2019 Sagi <sagiben@gmail.com>
- Version update to Kodi 18.1 Leia
* Sat Feb  2 2019 manfred.h@gmx.net
- Add BuildRequires:  pkgconfig(lirc)
* Wed Jan 30 2019 sagiben@gmail.com
- Version update to Kodi 18.0 Leia:
  http://kodi.wiki/view/Kodi_v18_(Leia)_changelog
* Tue Jan  8 2019 manfred.h@gmx.net
- kodi-libdrm.patch: Add patch to ensure DRM_FORMAT_GR1616 is defined.
* Wed Jan 31 2018 guillaume@opensuse.org
- Add missing 'l' alias
- Fix conflict between kodi and kodi-noX packages
* Tue Jan 30 2018 guillaume@opensuse.org
- Enable build for %%arm and aarch64 for kodi only
* Fri Dec 22 2017 olaf@aepfle.de
- Version update to Kodi 17.6 Krypton
* Sun Dec 10 2017 olaf@aepfle.de
- Remove netcdf from BuildRequires
  SLE_12 does not support it, and the private copy of ffmpeg will
  most likely work just fine without it
* Mon Nov 20 2017 davejplater@gmail.com
- Build with kodi's ffmpeg, version 17.x doesn't work with
  ffmpeg 3.4.
- Added kodi-tools-libdir.patch to fix libdvd build.
- Added unneeded return to switch statements in libdvdnav-master
  vmget.c to silence rpmlint errors.
* Sat Oct 28 2017 sagiben@gmail.com
- Version update to Kodi 17.5 Krypton
* Mon Oct 23 2017 olaf@aepfle.de
- Use BuildRequires and configure options as checked by configure.ac
* Thu Oct 12 2017 guillaume@opensuse.org
- Remove obsolete patch: add_rpi2_support.patch
* Wed Aug 23 2017 sagiben@gmail.com
- Version update to Kodi 17.4 Krypton
* Fri May 26 2017 sagiben@gmail.com
- Version update to Kodi 17.3 Krypton
  A minor bug fix and security release
* Wed May 24 2017 sagiben@gmail.com
- Version update to Kodi 17.2 Krypton
* Tue Mar 21 2017 sagiben@gmail.com
- Version update to Kodi 17.1 Krypton
* Wed Mar  1 2017 olaf@aepfle.de
- Make libbluray support optional
* Wed Mar  1 2017 sagiben@gmail.com
- Enable DVD support
  Use libdvdnav, libdvdcss, libdvdread from Kodi source
* Thu Feb 16 2017 sagiben@gmail.com
- Version update to Kodi 17.0 Krypton:
  http://kodi.wiki/view/Kodi_v17_(Krypton)_changelog
* Sat Aug  6 2016 olaf@aepfle.de
- Remove unused libhdhomerun dependency
* Fri Jul 29 2016 olaf@aepfle.de
- kodi.cximage.gcc6.patch
* Sun Apr 24 2016 sagiben@gmail.com
- Version update to Kodi 16.1 Jarvis:
  https://kodi.tv/kodi-16-1-jarvis-mark-xvi
* Thu Mar 31 2016 obs@botter.cc
- reintroduce fix __date__ macro in PythonSwig.cpp.template from Jan 16 2015
* Thu Mar 10 2016 guillaume@opensuse.org
- Add add_rpi2_support.patch to add raspberry pi2 platform support
* Wed Mar  9 2016 guillaume@opensuse.org
- BuildRequires ftgl-devel and libva only for openGL builds
- Remove libplatform dep since it was/is an addon dep
* Thu Feb 25 2016 sagiben@gmail.com
- Version update to Kodi 16.0 Jarvis:
  http://kodi.wiki/view/Kodi_v16_(Jarvis)_changelog
* Fri Jan 29 2016 guillaume@opensuse.org
- Remove SDL2 dep for kodi-noX* builds
- Rework again platform and player management
* Tue Jan 19 2016 sagiben@gmail.com
- Merge Kenneth Perry change to re-enabled joystick support
* Thu Jan 14 2016 guillaume@opensuse.org
- Rework platform and player management to ease new platforms and
  players additions
- Add new flavors :
  * 'raspberry-pi' armv6 platform flavor (kodi-noX-raspberry-pi)
  * 'raspberry-pi2' armv7 platform flavor (kodi-noX-raspberry-pi2)
* Mon Oct 26 2015 sagiben@gmail.com
- Version update to Kodi 15.2 Isengard Final release
  http://kodi.tv/kodi-15-2-isengard-final-release/
* Mon Oct 19 2015 guillaume@opensuse.org
- Fix Tumbleweed build by adding: 'BuildRequires:  pkgconfig(udev)'
  Otherwise fails with configure error on libcec because udev.pc
  file is not found
* Fri Oct 16 2015 guillaume@opensuse.org
- Add systemd *.service files
* Mon Aug 17 2015 sagiben@gmail.com
- Version update to Kodi 15.1 Isengard Maintenance release
  http://kodi.tv/kodi-15-1-isengard-maintenance-release/
* Sat Aug  1 2015 sagiben@gmail.com
- Fix FindJsonCpp.cmake in some pvr.addons
* Thu Jul 23 2015 scarabeus@opensuse.org
- Run over with spec-cleaner
- kodi-xrandr is not around with noX variant
* Wed Jul 22 2015 scarabeus@opensuse.org
- Add hicolor-icon-theme to builddeps as that pkg provide some
  directories for us
* Wed Jul 22 2015 scarabeus@opensuse.org
- Tweak a bit download_pvr.sh to be easier to use
* Wed Jul 22 2015 sagiben@gmail.com scarabeus@opensuse.org
- Version update to Kodi 15.0 Isengard:
  http://kodi.wiki/view/Kodi_v15_(Isengard)_changelog
* Wed Jul  8 2015 olaf@aepfle.de
- Fix rsxs build in Factory
* Mon Apr 27 2015 aloisio@gmx.com
- Removed libhogweed2 build requirement to fix Factory/Tumbleweed
  build.
* Sat Mar 28 2015 sagiben@gmail.com
- Update to Kodi 14.2 Helix Bugfix release
  * Fix: Application stopped responding on Windows
  * Fix: Gap-less playback on MP3
  * Fix: Playback of rtmp protocol
  * Fix: Scanning of newly added episodes
  * Fix: Fix multipath source scanning
  * Fix: Loading external subtitles in some cases
  * Fix: packaging of PIL module on Android. This fixes some script error when using weather add-on
  * Fix: Fix video playback on all platform after refresh rate change
  * Fix: Various bugs that were present in PVR add-ons.
  * Fix: Save weather location
  * Fix: Fix filtering of foreign add-ons
  * Fix: ftps handling
* Sat Feb  7 2015 sagiben@gmail.com
- enable AirPlay support
* Tue Feb  3 2015 sagiben@gmail.com
- Update to Kodi 14.1 Helix Bugfix release
  * Fix: incorrect video screensize on Android AML devices
  * Fix: potential segfault when silencing audio
  * Fix: do not skip streaminfo if format is not know.
  * Fix: DXVA flickering on AMD
  * Fix: prevent possible over-flow in ALSA
  * Fix: possible sorting problems in library
  * Fix: possible problem in library navigation
  * Fix: don’t scroll text when it’s set to not do it
  * Fix: scroll text if it’s too long on spinner controls
  * Fix: don’t overlap PVR search labels
  * Fix: bug in DLNA client string on iOS
  * Fix: updated several PVR add-ons
  * Fix: remember played state of video when started from recently added
  * Fix: correct vsync on OSX
  * Fix: broken keyboard input
  * Fix: prevent crash on circular dependencies of add-ons
  * Fix: large file support on Android
  * Fix: random exiting on Android x86 builds (Nexus Player for example)
* Sat Jan 24 2015 obs@botter.cc
- Require: libnfs to access NFS sources (not automatically required)
* Fri Jan 16 2015 obs@botter.cc
- fix __date__ macro in PythonSwig.cpp.template
* Sat Jan 10 2015 obs@botter.cc
- delete RUNPATH from installed binary, fixes PM-130, referencing
  http://trac.kodi.tv/ticket/15497 and http://bugzilla.opensuse.org/show_bug.cgi?id=902421
- along the line ALSA support was included in Request #1545
* Fri Jan  9 2015 obs@botter.cc
- Require: xpdyinfo on != -noX version
* Thu Jan  8 2015 obs@botter.cc
- remove __DATE and __TIME__ from source tree and ffmpeg archive
* Fri Dec 12 2014 sagiben@gmail.com
- Update to Kodi 14.0 Helix
  * Project name was changed from XBMC to Kodi ( http://kodi.tv/introducing-kodi-14/ )
  * Different selectable keyboard layouts for the on screen keyboard.
  * Faster library scraping
  * Updated ffmpeg (2.4.4) including h.265 support
  * More control over add-ons and their updates in the add-on manager
  * "big font" size in Confluence
  * ATSC sub channels for PVR in the US
  * PVR window changes for easier navigation and new EPG views (now/next/channel)
  * Archives (zip, bin, etc) files can be directly browsed
* Wed Nov  5 2014 fisiu@opensuse.org
- Depends on xdpyinfo on x86{,-64}, fix pm#126.
* Sat Sep 13 2014 sagiben@gmail.com
- Update to 13.2
  * Bittstream conversion fix for some BD mkv iso rips
  * Fix labelcontrols with autowidth set were always marked as dirty (re-render)
  * Update included PVR add-on
  * Set “remote as keyboard” default to true for Android
  * Fix FTP TLS not working
  * Fix onplaybackstarted event for external players
  * Don’t show OSD menu DVD menu with mouse/touch
  * GetText and delete sound option for add-on developers
  * Fix overlapping subtitles
  * Fix accented letters. Example: “VARIéS” rather than “VARIÉS”
  * Prompt for master pin in case the add-on manager is locked
  * Update GUI translations
  * Update included add-ons
  * Fixed several bugs and memory leaks
* Tue Jun 10 2014 guillaume@opensuse.org
- Drop texture.patch since xbmc 13.1 does not need this fix anymore.
* Sat Jun  7 2014 fisiu@opensuse.org
- Update to 13.1:
  * Fix resume point of certain PVR items begin stale on playback.
  * Fix weirdness when certain TVs query XBMC’s UPnP server and it
    starts running a bunch of add-ons which cause popups on the XBMC
    machine.
  * Fix crash at exit while airplay is playing
  * Better recovery of VDPAU on errors.
  * Fixes for cropping of interlaced content using VDPAU.
  * Fix for FLAC tracks with large embedded images not playing.
  * Fix for crash if librtmp wasn’t available.
  * Fix for ffmpeg building on linux using later versions of librtmp.
  * Fix for broken m4a, mp4 playback with paplayer.
  * Fix for the hint text not being shown in editcontrols once unfocused.
  * Fix minor memory leak in PlayMedia builtin function.
  * Fix albumartist use in song smartplaylists.
  * Use unique client broadcast UID in the PVR api.
* Mon May 26 2014 guillaume@opensuse.org
- Fix build for non openGL builds (fix openGL ES)
- Run pre_checkin.sh script to sync xbmc-noX files
* Sat May 17 2014 fisiu@opensuse.org
- Update to 13.0 Gotham:
  * Dramatic Audio Engine Improvements
  * Improved UPnP capabilities
  * Settings Improvements
  * Making Subtitle Search Better
  * Stereoscopic 3D Rendering
  * Raspberry Pi and Android speed improvements
  * An Extended Python and JSON-RPC API for developers
  * Many minor fixes and improvements
- Add enable-external-ffmpeg.patch: build again system ffmpeg.
- Drop xbmc-12.2-subtitles.patch: fixed upstream.
- Drop samba4-fix.patch: fixed upstream.
- Drop git_rev.patch: fixed upstream.
* Mon Feb 17 2014 guillaume@opensuse.org
- Replace raspberrypi-gfx-devel package by raspberrypi-userland-devel
* Wed Feb 12 2014 guillaume@opensuse.org
- Add no X version support (mainly used by ARM boards)
* Fri Dec 27 2013 sagiben@gmail.com
- - New upstream version 12.3
* Wed Oct  2 2013 guillaume@opensuse.org
- Fix Raspberry Pi (armv6) build:
  * Add include path for raspberrypi-gfx headers
  * Add texture.patch to fix include path for XBMCTex.cpp
  * Add disable_omxplayer_3d_support.patch to disable 3D support
  from omxplayer since X11/GLES does not support it (only EGL)
* Mon Sep 16 2013 guillaume@opensuse.org
- Enable omxplayer by default (player for raspberry pi ARMv6 board)
* Mon Sep 16 2013 guillaume@opensuse.org
- Protect enable_rpi_build condition with %%ifarch armv6
* Mon Sep 16 2013 sagiben@gmail.com
- Enable MythTV pvr addon
- Set git revision
* Fri Sep 13 2013 guillaume@opensuse.org
- Add options to enable/disable openGL / openGL ES support
  * ARM default: openGL ES
  * Other arch: openGL
* Fri Sep 13 2013 guillaume@opensuse.org
- Add support for omxplayer for raspberry pi board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add support for Raspberry Pi ARM board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add libcec and airplay support
* Wed Sep  4 2013 fisiu@opensuse.org
- Add samba4-fix.patch: fix build against samba4 - enabled for
  openSUSE >= 13.1.
* Wed Sep  4 2013 fisiu@opensuse.org
- Add Requires: Mesa-demo-x for openSUSE >= 12.2, fix pm#84.
* Mon Aug 26 2013 guillaume@opensuse.org
- Make use of %%configure macro
* Fri Aug 23 2013 guillaume@opensuse.org
- Fix builds:
  * XBMC 12.2 depends on FFMPEG1, not FFMPEG2
  * crystalhd is only built for x86/x86_64
* Mon Jun  3 2013 fisiu@opensuse.org
- Add xbmc-12.2-subtitles.patch: embeded fonts' rendering fix.
* Fri May 10 2013 sagiben@gmail.com
- New upstream version 12.2
* Fri Mar 29 2013 sagiben@gmail.com
- New upstream version 12.1
* Mon Feb  4 2013 fisiu@opensuse.org
- Spec file cleanup.
- Enable support for airplay.
- Detect libtag version and use it as Requires.
* Sun Feb  3 2013 p.seiler@linuxmail.org
- small changes in the spec file for cleanness
  replaced BuildRequires to simple java
  removed outcommented stuff like BuildRequires and so on
* Fri Feb  1 2013 hvogel@opensuse.org
-Include PVR add-ons, they are the main feature of Frodo
* Fri Feb  1 2013 p.seiler@linuxmail.org
- added explizit libtag-devel 1.8 requirement to prevent conflict with openSUSE libtag package
* Thu Jan 31 2013 p.seiler@linuxmail.org
- corrected licenses in spec file to prevent build warning
- added devel package to prevent build error
* Wed Jan 30 2013 p.seiler@linuxmail.org
- new upstream version 12.0
  + HD audio support, including DTS-MA and Dolby True-HD, via the
  new XBMC AudioEngine
  + Live TV and PVR support
  + h.264 10bit (aka Hi10P) video software decoding for anime
  + Improved image support, allowing the database to accomodate
  numerous additional image types
  + Improved Airplay support across all platforms
  + Improved controller support
  + Advanced Filtering in the library
  + Advanced UPnP sharing
  + Translations now powered by Transifex
  Sun Apr  8 14:39:48 UTC 2012 - sagiben at gmail com
- New upstream version 11.0
* Fri Dec  9 2011 ismail@namtrac.org
- Remove _service its fragile
- Spec cleanup
* Thu Dec  8 2011 ismail@namtrac.org
- Depend on libbluray1
* Mon Nov 28 2011 sagiben@gmail.com
- fix build with gcc-4.6. Flags to the Linker must be passed via -Wl,.
  Patch was taken from xbmc ticket #11383, http://trac.xbmc.org/ticket/11383
* Tue May  3 2011 fisiu@opensuse.org
- disable-hal for openSUSE >= 11.4
* Fri Apr 15 2011 andrea@links2linux.de
- New upstream version 10.1
* Mon Jan 24 2011 andrea@links2linux.de
- enabled crystalhd and bluray support (dependencies now available)
* Mon Jan 24 2011 andrea@links2linux.de
- enabled VA-API (not sure if it works), FAAC, ssh, optimizations
* Wed Jan 12 2011 andrea@links2linux.de
- New upstream version 10.0 (Thanks fedora)
* Sun Feb  7 2010 andrea@links2linux.de
- fixed docs location
* Sat Feb  6 2010 andrea@links2linux.de
- added bool.patch to fix a startup segmentation fault
- do NOT use ffmpeg external libraries because they make xbmc crashes when you try to reproduce a video
